# Cepton SDK Python Release Notes

### Version 0.3 (beta) 2018-06-06
* Update SDK binaries.
* Add export points sample.

### Version 0.2 (beta) 2018-06-20
* Add cepton_util.

### Version 0.1 (beta) 2018-05-01
* Initial release.